function [ECStruct,Cout,ea]=mkOlivine_str2010(flg_data)
% function to load  structure "ECStruct" with all the needed data and
% options and to set initial guesses for elastic constnats
%  Usage: [ECStruct,Cout,ea]=mkOlivine_str2010(flg_data)
% where Cout is a vector of constants, ea is a matrix of euler angels,
% ECStruct contains everything and flg_data is a flag to determine whether
% to use actual measured data (flg_data='n') or synthetic data created with
% uncertainties: flg_data='s';
% the experimental data is the set sent by Jia Chen on July 27, 2010
%
%  calls dcos2ea, symcode, xstl
% jmb 7/2010

 ECStruct.Data.name='Olivine';
% notes:
% density:3.355 (g/cm3)
% column 1-3: phonon direction
% column 4: vp (m/s)
% column 5-6: vs1 and vs2 (m/s)
 
 ECStruct.Data.nsamp=1;
 ECStruct.Data.sym='o';
 ECStruct.Data.rho=3.355;

Ctemp=[ 
  320.5
  196.5
  233.5
   64.0
   77.0
   78.7  
   68.1
   71.6
   76.8
];
ECStruct.Data.Cguess=Ctemp(:,1);

% OLivine 02-17-10
 %RUN --     3- 8-2010    4:33: 9
data=[-.1775  .8304  .5282  7739.4 4844.6 4501.1 
-.0439  .7786  .6260  7771.7 4766.1 4509.8 
 .0233  .7435  .6683  7853.9 4762.2 4545.7 
 .0900  .7026  .7059  7905.0 4765.5 4517.7 
 .2204  .6049  .7652  8005.2 4883.7 4483.7 
 .3436  .4885  .8021  8092.2 5077.9 4477.3 
 .4014  .4244  .8116  8151.7 5133.2 4462.9 
 .4562  .3572  .8151  8289.7 5211.5 4458.6 
 .5551  .2152  .8035  8364.4 5349.9 4494.6 
 .6378  .0671  .7673  8551.3 5439.4 4511.3 
 .6722 -.0078  .7403  8611.2 5411.9 4543.4 
 .7019 -.0825  .7075  8688.6     nan 4562.9 
 .7457 -.2291  .6257  8783.6 5308.1 4616.9 
 .7680 -.3680  .5242  8897.6     nan 4647.7 
 .7708 -.4334  .4669  8787.6    nan 4657.1 
 .7680 -.4953  .4060  8776.4     nan 4645.2
 .7454 -.6073  .2748  8691.9 5076.2 4583.2 
 .7006 -.7007  .1348  8476.0 5077.9 4531.3 
 .6702 -.7395  .0629  8388.0 5068.0 4498.2 
 .6345 -.7728 -.0095  8243.9 5055.2 4466.5 
 .5488 -.8218 -.1535  8078.3 5046.6 4445.7 
 .4455 -.8462 -.2924  7887.2 5007.4 4476.2
 .3883 -.8490 -.3585  7814.8 4971.0 4466.8 
 .3277 -.8454 -.4217  7808.3 4935.9 4507.7 
 .1988 -.8197 -.5372  7754.2 4821.9     nan 
% .0626 -.7697 -.6353  7758.0 4782.0     nan 
%-.0069 -.7360 -.6769  7797.6 4760.3 4479.6
];

[ea1,angles1]=dcos2ea(data(:,1:3),10);


% the following 6 lines create a synthetic data set with uncertainty
na=length(angles1);
[Sid,scode]=symcode(7);
velc=xstl(data(:,1:3),3.355,Ctemp(Sid),7);
fac=.003;  %  fractional uncertainty
errors=(1+fac*randn(size(velc)));
velc=errors.*velc;
% end of synthetic data creation


ECStruct.Data.eulerangles=[ea1(:)  ]; % in this case the euler angles are a vector (one sample). In general this will be a matrix


  ECStruct.Data.sample(1).name='Olivine diagonal';
% load real data
  ECStruct.Data.sample(1).BWvelocities= data(:,[6 5 4])/1e3;
% load synthetic "data"
   if strcmp(flg_data,'s')
     ECStruct.Data.sample(1).BWvelocities= velc;
   end
   
ECStruct.Data.sample(1).BWangles= angles1(:);
ECStruct.Data.sample(1).BWuncertainties=fac*ECStruct.Data.sample(1).BWvelocities;
 
  
  
ECStruct.opts.eulerfit='no';
ECStruct.opts.eulernum=[];
ECStruct.opts.eulerangles=ECStruct.Data.eulerangles;
ECStruct.opts.constants=ECStruct.Data.Cguess;
ECStruct.opts.ifit=1:ECStruct.Data.nsamp;
ECStruct.opts.iconst=1:length(ECStruct.Data.Cguess);


ECStruct.Data.Trust=[ 50   400
  50 400
   50  400
    15    100
    15    100
    15    100
    15    100
    15    100
    10    100];

Cout=ECStruct.Data.Cguess;
ea=ECStruct.Data.eulerangles;
ECStruct.opts.fun_count=0;
ECStruct.opts.flg_jacb='n';
ECStruct.opts.pltRange=180;